@@ -219,7 +219,7 @@ sub cud {
         attrs => { type => ARRAYREF }, # order of attrs must match SQL statement
     } );
 
-    my ( $status, $rv );
+    my ( $status, $rv, $count );
 
     try {
         local $SIG{__WARN__} = sub {
@@ -254,9 +254,13 @@ sub cud {
                 # populate object with all RETURNING fields 
                 map { $ARGS{'object'}->{$_} = $rh->{$_}; } ( keys %$rh );
 
+                # count number of rows affected
+                $count = $sth->rows;
+
             } elsif ( $rv eq '0E0' ) {
 
                 # no error, but no record returned either
+                $count = $sth->rows;
 
             } elsif ( $rv > 1 ) {
                 $status = $CELL->status_crit( 
@@ -279,12 +283,21 @@ sub cud {
             $errmsg = '<NONE>';
         }
         if ( not defined( $status ) ) {
-            $status = $CELL->status_err( 'DOCHAZKA_DBI_ERR', args => [ $errmsg ] );
+            $status = $CELL->status_err( 'DOCHAZKA_DBI_ERR', 
+                args => [ $errmsg ],
+                DBI_return_value => $rv,
+            );
         }
     };
 
-    $status = $CELL->status_ok( 'DOCHAZKA_CUD_OK', DBI_return_value => $rv, payload => $ARGS{'object'} ) 
-        unless $status;
+    if ( not defined( $status ) ) {
+        $status = $CELL->status_ok( 'DOCHAZKA_CUD_OK', 
+            DBI_return_value => $rv,
+            payload => $ARGS{'object'}, 
+            count => $count,
+        );
+    }
+
     return $status;
 }
 
@@ -327,13 +340,13 @@ sub cud_generic {
         conn => { isa => 'DBIx::Connector' },
         eid => { type => SCALAR },
         sql => { type => SCALAR }, 
-        bind_params => { type => ARRAYREF }, # order must match SQL statement
+        bind_params => { type => ARRAYREF, optional => 1 }, # order must match SQL statement
     } );
     $log->info( "Entering " . __PACKAGE__ . "::cud_generic with" );
     $log->info( "sql: $ARGS{sql}" );
     $log->info( "bind_param: " . Dumper( $ARGS{bind_params} ) );
 
-    my ( $status, $rv );
+    my ( $status, $rv, $count );
 
     try {
         local $SIG{__WARN__} = sub {
@@ -362,11 +375,13 @@ sub cud_generic {
             $log->debug( "cud_generic: DBI execute returned " . Dumper( $rv ) );
             if ( $rv >= 1 ) {
 
-                # one or more records returned
+                # count number of rows affected
+                $count = $sth->rows;
 
             } elsif ( $rv eq '0E0' ) {
 
                 # no error, but no record returned either
+                $count = $sth->rows;
 
             } elsif ( $rv == -1 ) {
                 $status = $CELL->status_err( 
@@ -384,12 +399,20 @@ sub cud_generic {
             $errmsg = '<NONE>';
         }
         if ( not defined( $status ) ) {
-            $status = $CELL->status_err( 'DOCHAZKA_DBI_ERR', args => [ $errmsg ] );
+            $status = $CELL->status_err( 'DOCHAZKA_DBI_ERR', 
+                args => [ $errmsg ],
+                DBI_return_value => $rv,
+            );
         }
     };
 
-    $status = $CELL->status_ok( 'DOCHAZKA_CUD_OK', payload => $rv ) 
-        unless $status;
+    if ( not defined( $status ) ) {
+        $status = $CELL->status_ok( 'DOCHAZKA_CUD_OK', 
+            DBI_return_value => $rv, 
+            count => $count,
+        );
+    }
+
     return $status;
 }
 
@@ -960,7 +983,7 @@ sub tsrange_intersection {
 
     my $status = select_single(
         conn => $conn,
-        sql => 'SELECT CAST( ? AS tsrange) * CAST( ? AS tsrange )',
+        sql => 'SELECT CAST( ? AS tstzrange) * CAST( ? AS tstzrange )',
         keys => [ $tr1, $tr2 ],
     );
     die $status->text unless $status->ok;
@@ -980,7 +1003,7 @@ sub tsrange_equal {
 
     my $status = select_single(
         conn => $conn,
-        sql => 'SELECT CAST( ? AS tsrange) = CAST( ? AS tsrange )',
+        sql => 'SELECT CAST( ? AS tstzrange) = CAST( ? AS tstzrange )',
         keys => [ $tr1, $tr2 ],
     );
     die $status->text unless $status->ok;
